Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
jbank/__init__.py | 1 | 0 | 0 | 100%
jbank/admin.py | 794 | 409 | 0 | 48%
jbank/aeb43.py | 81 | 81 | 0 | 0%
jbank/apps.py | 6 | 0 | 0 | 100%
jbank/camt.py | 365 | 56 | 0 | 85%
jbank/csr_helpers.py | 44 | 13 | 0 | 70%
jbank/ecb.py | 18 | 2 | 0 | 89%
jbank/euribor.py | 33 | 33 | 0 | 0%
jbank/files.py | 15 | 2 | 0 | 87%
jbank/helpers.py | 58 | 13 | 0 | 78%
jbank/management/__init__.py | 0 | 0 | 0 | 100%
jbank/management/commands/__init__.py | 0 | 0 | 0 | 100%
jbank/management/commands/make_pain001.py | 66 | 66 | 0 | 0%
jbank/management/commands/make_parse_format.py | 46 | 46 | 0 | 0%
jbank/management/commands/make_x509.py | 29 | 29 | 0 | 0%
jbank/management/commands/parse_aeb43.py | 24 | 24 | 0 | 0%
jbank/management/commands/parse_ecb_rates.py | 48 | 48 | 0 | 0%
jbank/management/commands/parse_euribor_rates.py | 21 | 21 | 0 | 0%
jbank/management/commands/parse_ra.py | 22 | 22 | 0 | 0%
jbank/management/commands/parse_saldo.py | 22 | 22 | 0 | 0%
jbank/management/commands/parse_svm.py | 61 | 14 | 0 | 77%
jbank/management/commands/parse_to.py | 60 | 14 | 0 | 77%
jbank/management/commands/parse_x509.py | 13 | 13 | 0 | 0%
jbank/management/commands/parse_xm.py | 52 | 5 | 0 | 90%
jbank/management/commands/parse_xp.py | 62 | 62 | 0 | 0%
jbank/management/commands/parse_xt.py | 109 | 58 | 0 | 47%
jbank/management/commands/reparse_svm.py | 27 | 27 | 0 | 0%
jbank/management/commands/reparse_to.py | 27 | 27 | 0 | 0%
jbank/management/commands/test_app_req.py | 25 | 14 | 0 | 44%
jbank/management/commands/test_pain001.py | 32 | 17 | 0 | 47%
jbank/management/commands/test_payment.py | 21 | 10 | 0 | 52%
jbank/management/commands/test_svm.py | 11 | 3 | 0 | 73%
jbank/management/commands/test_to.py | 11 | 3 | 0 | 73%
jbank/management/commands/test_xp.py | 16 | 8 | 0 | 50%
jbank/management/commands/wsedi_download.py | 86 | 86 | 0 | 0%
jbank/management/commands/wsedi_exec.py | 44 | 44 | 0 | 0%
jbank/management/commands/wsedi_export.py | 39 | 39 | 0 | 0%
jbank/management/commands/wsedi_import.py | 49 | 49 | 0 | 0%
jbank/management/commands/wsedi_upload.py | 76 | 76 | 0 | 0%
jbank/management/commands/wspki_exec.py | 37 | 37 | 0 | 0%
jbank/management/commands/xmlsec1_examples.py | 19 | 19 | 0 | 0%
jbank/models.py | 620 | 132 | 0 | 79%
jbank/pain002.py | 31 | 31 | 0 | 0%
jbank/parsers.py | 151 | 52 | 0 | 66%
jbank/sepa.py | 195 | 25 | 0 | 87%
jbank/services.py | 6 | 6 | 0 | 0%
jbank/svm.py | 154 | 16 | 0 | 90%
jbank/templates/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/jbank/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/jbank/referencepaymentbatch/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/jbank/statement/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/jbank/__init__.py | 0 | 0 | 0 | 100%
jbank/tests.py | 167 | 0 | 0 | 100%
jbank/tito.py | 149 | 25 | 0 | 83%
jbank/views.py | 0 | 0 | 0 | 100%
jbank/wsedi.py | 120 | 120 | 0 | 0%
jbank/wspki.py | 257 | 257 | 0 | 0%
jbank/x509_helpers.py | 21 | 11 | 0 | 48%
manage.py | 13 | 6 | 0 | 54%
Total | 4454 | 2193 | 0 | 51%

No items found using the specified filter.